pure_eval: Safely evaluate AST nodes without side effects
=========================================================

Description
-----------

Safely evaluate AST nodes without side effects

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pure-eval/

